function createfigure(xdata1, ydata1, zdata1, cdata1)
%CREATEFIGURE(XDATA1, YDATA1, ZDATA1, CDATA1)
%  XDATA1:  surface xdata
%  YDATA1:  surface ydata
%  ZDATA1:  surface zdata
%  CDATA1:  surface cdata

%  Auto-generated by MATLAB on 26-Oct-2014 14:05:39

% Create figure
figure1 = figure;

% Create axes
axes1 = axes('Parent',figure1);
view(axes1,[-64.5 22]);
grid(axes1,'on');
hold(axes1,'on');

% Create surf
surf(xdata1,ydata1,zdata1,cdata1,'Parent',axes1,'LineStyle','none');

